@@ -11,7 +11,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(setup_snippet_with_id);
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 our %SPEC;
 
@@ -449,7 +449,7 @@ Setup::Text::Snippet::WithID - Setup text snippet (with comment containing ID) i
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -489,20 +489,10 @@ Example of multi-line snippet, in INI-style comment instead of shell-style:
 
 =head1 DESCRIPTION
 
-This module provides one function: B<setup_snippet_with_id>.
-
-This module is part of the Setup modules family.
-
 This module uses L<Log::Any> logging framework.
 
 This module has L<Rinci> metadata.
 
-=head1 THE SETUP MODULES FAMILY
-
-I use the C<Setup::> namespace for the Setup modules family. See C<Setup::File>
-for more details on the goals, characteristics, and implementation of Setup
-modules family.
-
 =head1 BUGS/TODOS/LIMITATIONS
 
 If a snippet is removed due to should_exist=>0, its position is not recorded.
@@ -516,7 +506,7 @@ TODO: Restore attrs.
 
 =head1 SEE ALSO
 
-Other modules in Setup:: namespace.
+L<Setup>
 
 =head1 AUTHOR
 
